==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/fa/admin/statuslabels/message.php <==
<?php

return array(

    'does_not_exist' => 'برچسب وضعیت موجود نیست',
    'assoc_assets'	 => 'این برچسب وضعیت در حال حاضر حداقل با یک دارایی همراه است و نمی تواند حذف شود. لطفا دارایی های خود را به روز کنید تا دیگر این وضعیت را رد نکنید و دوباره امتحان کنید.',


    'create' => array(
        'error'   => 'برچسب وضعیت ایجاد نشد، لطفا دوباره امتحان کنید',
        'success' => 'برچسب وضعیت با موفقیت ایجاد شد'
    ),

    'update' => array(
        'error'   => 'برچسب وضعیت به روز نشده است، لطفا دوباره امتحان کنید',
        'success' => 'برچسب وضعیت با موفقیت به روز شد.'
    ),

    'delete' => array(
        'confirm'   => 'آیا مطمئنید که میخواهید این برچسب وضعیت را حذف کنید؟',
        'error'   => 'یک مسئله حذف برچسب وضعیت وجود داشت. لطفا دوباره تلاش کنید.',
        'success' => 'برچسب وضعیت با موفقیت حذف شد.'
    ),

    'help' => array(
        'undeployable'   => 'این دارایی ها را نمی توان به کسی اختصاص داد.',
        'deployable'   => 'این دارایی ها را می توان بررسی کرد. هنگامی که آنها اختصاص داده می شوند، آنها متا وضعیت <i class="fa fa-circle text-blue"></i> <strong>Deployed</strong> را در نظر می گیرند.',
        'archived'   => 'این دارایی ها قابل چک نیست و فقط در نمای Archived نمایش داده می شوند. این امر برای حفظ اطلاعات مربوط به دارایی ها برای بودجه بندی / اهداف تاریخی مفید است اما نگه داشتن آنها از فهرست دارایی روزمره.',
        'pending'   => 'این دارایی ها هنوز نمی توانند به هر کسی اختصاص داده شوند، که اغلب برای مواردی که برای تعمیر وجود دارد، مورد استفاده قرار می گیرند، اما انتظار می رود که به گردش درآید.',
    ),

);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/fa/admin/statuslabels/message.php <==
<?php

return [

    'does_not_exist' => 'برچسب وضعیت موجود نیست',
    'assoc_assets'	 => 'این برچسب وضعیت در حال حاضر حداقل با یک دارایی همراه است و نمی تواند حذف شود. لطفا دارایی های خود را به روز کنید تا دیگر این وضعیت را رد نکنید و دوباره امتحان کنید.',

    'create' => [
        'error'   => 'برچسب وضعیت ایجاد نشد، لطفا دوباره امتحان کنید',
        'success' => 'برچسب وضعیت با موفقیت ایجاد شد',
    ],

    'update' => [
        'error'   => 'برچسب وضعیت به روز نشده است، لطفا دوباره امتحان کنید',
        'success' => 'برچسب وضعیت با موفقیت به روز شد.',
    ],

    'delete' => [
        'confirm'   => 'آیا مطمئنید که میخواهید این برچسب وضعیت را حذف کنید؟',
        'error'   => 'یک مسئله حذف برچسب وضعیت وجود داشت. لطفا دوباره تلاش کنید.',
        'success' => 'برچسب وضعیت با موفقیت حذف شد.',
    ],

    'help' => [
        'undeployable'   => 'این دارایی ها را نمی توان به کسی اختصاص داد.',
        'deployable'   => 'این دارایی ها قابل بررسی هستند. هنگامی که آن‌ها تخصیص داده شدند، وضعیت متا <i class="fas fa-circle text-blue"></i> <strong>Deployed</strong> نظر گرفته می‌شود.',
        'archived'   => 'این دارایی ها قابل چک نیست و فقط در نمای Archived نمایش داده می شوند. این امر برای حفظ اطلاعات مربوط به دارایی ها برای بودجه بندی / اهداف تاریخی مفید است اما نگه داشتن آنها از فهرست دارایی روزمره.',
        'pending'   => 'این دارایی ها هنوز نمی توانند به هر کسی اختصاص داده شوند، که اغلب برای مواردی که برای تعمیر وجود دارد، مورد استفاده قرار می گیرند، اما انتظار می رود که به گردش درآید.',
    ],

];
